# talon
A pure Python package that implements Tractograms As Linear Operators in 
Neuroimaging.

## Installation

For now, most people are expected to use `talon` as developers and should
 install it by moving into the root `talon` directory and running:
```bash
python setup.py develop
```
To make sure `talon` was installed correctly, test it by running:
```bash
python -m unittest
```

## Documentation

Generating the documentation requires the `sphinx` package.
It can be installed by running:
```bash
pip install sphinx
```

The documentation can then be compiled by moving into the `talon/doc` directory and running:
```bash
make html
```

The root of the documentation is `talon/doc/build/html/index.html`.

## Quickstart

Coming soon!

